<div align="center">

  # ⚒ devgoldyutils
  
  <sub>My own utils library I use throughout all my python projects.</sub>
  
  [![Pypi Badge](https://img.shields.io/pypi/v/devgoldyutils?style=flat)](https://pypi.org/project/GoldyBot/ "We're on pypi!")
  [![Python Badge](https://img.shields.io/pypi/pyversions/devgoldyutils?style=flat)](https://pypi.org/project/GoldyBot/ "Supported python versions.")
  
</div>

> whoo hooo, yeahhh
